@@ -1,9 +1,11 @@
 from appconf import AppConf
 from django.conf import settings
+import os
 
 
 class CustomAdminConf(AppConf):
     STATIC_URL = u'/static/'
+    STATIC_ROOT = os.path.join(os.getcwd(), 'static')
     USE_CUSTOM_ADMIN = True
 
     def configure_static_url(self, value):
@@ -12,6 +14,12 @@ class CustomAdminConf(AppConf):
             return value
         return getattr(settings, 'STATIC_URL')
 
+    def configure_static_root(self, value):
+        if not getattr(settings, 'STATIC_ROOT', None):
+            self._meta.holder.STATIC_ROOT = value
+            return value
+        return getattr(settings, 'STATIC_ROOT')
+
     def configure_use_custom_admin(self, value):
         if not getattr(settings, 'USE_CUSTOM_ADMIN', None):
             self._meta.holder.USE_CUSTOM_ADMIN = value
